function rates = crdot( t, y, dummyflag, p, q, omc, omr )
%  given y=[ c r ] return rates = [dc/dt dr/dt]
%  dc/dt = omc * A * r * c^p * sqrt( 1- c )
%  dr/dt = omr * ( Req(c) - r )
%  A is such that max(dc/dt) = omc, for r=R(c) 

c = y(1);
r = y(2);

cmax = q./(q+.5);
Rmax = cmax.^q .* sqrt(1-cmax);
cbar = (p+q)./(1+p+q);
A = Rmax/( cbar.^(p+q) .* (1-cbar) );

cc = max([1-c 0]);
dcdt = omc .* A.* r .* c.^p .* sqrt(cc);
drdt = omr .* ( Req(c,q) - r );

rates = [ dcdt drdt ]';
